# VencoPy description for contributors file
- Author: Niklas Wulff
- Contact: niklas.wulff@dlr.de
- Version: 0.0.8 (pre-release)

Contributing to VencoPy 
===========================


Thanks for your interest in this project.

Project description
----------------------

Vehicle Energy Consumption in Python (VencoPy) is a tool that provides boundary conditions for load shifting and vehicle-to-grid potentials based on transport demand data and techno-economic assumptions. Read more here::

    [Link to readthedocs]


Developer resources
---------------------

Information regarding code structure, design principles and architecture choices can be found in the VencoPy documentation. If you wish to contribute, feel free to get in touch with Niklas at DLR: niklas.wulff@dlr.de or open an issue on the repository. In its alpha release, we currently don't support automatic pushes. 

The project maintains the following source code repositories

    https://gitlab.dlr.de/vencopy/vencopy

We are happily reviewing issues that we receive via the repository.


Contributor license agreement
------------------------------

Before your contribution can be accepted by the project team contributors must electronically sign the End-user license agreement in line with the DLR standards. A respective file is shipped with the repository. Please fill out your credentials and send it to niklas.wulff@dlr.de.